@@ -459,7 +459,10 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         response = self._get("/showvs", self._get_base_parameters())
         data = get_data(response)
         real_servers = []
-        for server in data.get('Rs', []):
+        servers = data.get('Rs', [])
+        if not isinstance(servers, list):
+            servers = [servers]
+        for server in servers:
             real_server = self.build_real_server(server)
             real_servers.append(real_server)
         return real_servers
